# wradvis_hc_amo minhcuong.today
minhcuong.today
wradvis is intended as an application based on the [wradlib](http://wradlib.org) library.

Its prime motivation is to provide a convenient application for viewing weather radar data.
However, wradvis might also contain simple analytical features, e.g. for computing zonal statistics.

Right now, wradvis is still in the design process. Further information will follow once we have a basic prototype.